summaryrefslogtreecommitdiffstats
path: root/models/migrations
diff options
context:
space:
mode:
authorBwko <bouwko@gmail.com>2016-12-28 09:33:21 +0100
committerLunny Xiao <xiaolunwen@gmail.com>2016-12-28 16:33:21 +0800
commit331316894e391beb29fdebf9d8088973759bba1c (patch)
treee80827f0c2a87006c1601d3f1e93611644722a3a /models/migrations
parentf686a32eac75460d5b1fcf16b6f6c2ed57f5b03e (diff)
downloadgitea-331316894e391beb29fdebf9d8088973759bba1c.tar.gz
gitea-331316894e391beb29fdebf9d8088973759bba1c.zip
Replace Gogs with Gitea (#520)
Diffstat (limited to 'models/migrations')
-rw-r--r--models/migrations/migrations.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/models/migrations/migrations.go b/models/migrations/migrations.go
index 6393747b0e..66f80dac30 100644
--- a/models/migrations/migrations.go
+++ b/models/migrations/migrations.go
@@ -103,13 +103,13 @@ func Migrate(x *xorm.Engine) error {
v := currentVersion.Version
if minDBVersion > v {
- log.Fatal(4, `Gogs no longer supports auto-migration from your previously installed version.
+ log.Fatal(4, `Gitea no longer supports auto-migration from your previously installed version.
Please try to upgrade to a lower version (>= v0.6.0) first, then upgrade to current version.`)
return nil
}
if int(v-minDBVersion) > len(migrations) {
// User downgraded Gogs.
currentVersion.Version = int64(len(migrations) + minDBVersion)
_, err = x.Id(1).Update(currentVersion)
return err
@@ -103,13 +103,13 @@ func Migrate(x *xorm.Engine) error {
}
if int(v-minDBVersion) > len(migrations) {
- // User downgraded Gogs.
+ // User downgraded Gitea.
currentVersion.Version = int64(len(migrations) + minDBVersion)
_, err = x.Id(1).Update(currentVersion)